# Reticulator


Reticulator is a pack-access library for Minecraft Bedrock Addons.
Reticulator functions by exposing json files as a nested tree of python
classes. This structure allows you to interact with an addon as if it
was an API.